@@ -12,6 +12,8 @@
 
 #include <QVariant>
 
+#include <memory>
+
 namespace KContacts
 {
 class ContactGroup;
@@ -20,6 +22,7 @@ class ContactGroup;
 namespace Akonadi
 {
 class Item;
+class AbstractContactGroupFormatterPrivate;
 
 /**
  * @short The interface for all contact group formatters.
@@ -105,8 +108,7 @@ private:
     //@cond PRIVATE
     Q_DISABLE_COPY(AbstractContactGroupFormatter)
 
-    class Private;
-    Private *const d;
+    std::unique_ptr<AbstractContactGroupFormatterPrivate> const d;
     //@endcond
 };
 }
