@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_DIALPHONENUMBERACTION_H
-#define AKONADI_DIALPHONENUMBERACTION_H
+#pragma once
 
 namespace KContacts
 {
@@ -28,4 +27,3 @@ public:
 };
 }
 
-#endif
