@@ -13,8 +13,8 @@
 CategoriesEditWidget::CategoriesEditWidget(QWidget *parent)
     : ContactEditor::CategoriesEditAbstractWidget(parent)
 {
-    auto *layout = new QHBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto layout = new QHBoxLayout(this);
+    layout->setContentsMargins({});
 }
 
 CategoriesEditWidget::~CategoriesEditWidget()
